@@ -10,6 +10,7 @@
 #include <QColor>
 #include <QImage>
 #include <QObject>
+#include <qqmlregistration.h>
 
 /**
  * @brief Main class that expose all the value to the QML.
@@ -17,6 +18,8 @@
 class Kontrast : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
 
     Q_PROPERTY(QColor textColor READ textColor WRITE setTextColor NOTIFY textColorChanged)
 
@@ -69,7 +72,7 @@ public:
     };
 
     QColor textColor() const;
-    void setTextColor(const QColor textColor);
+    void setTextColor(const QColor &textColor);
 
     int textHue() const;
     void setTextHue(int hue);
@@ -84,7 +87,7 @@ public:
     void setFontSize(int fontSize);
 
     QColor backgroundColor() const;
-    void setBackgroundColor(const QColor backgroundColor);
+    void setBackgroundColor(const QColor &backgroundColor);
 
     int backgroundHue() const;
     void setBackgroundHue(int hue);
